==> cxf-testutils-2.0.6.16-fuse-sources.jar: org/apache/type_test/types1/StructWithUnion.java <==

package org.apache.type_test.types1;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for StructWithUnion complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="StructWithUnion">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="varUnion" type="{http://apache.org/type_test/types1}SimpleUnion"/>
 *       &lt;/sequence>
 *       &lt;attribute name="attribUnion" type="{http://apache.org/type_test/types1}SimpleUnion" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "StructWithUnion", propOrder = {
    "varUnion"
})
public class StructWithUnion {

    @XmlElement(namespace = "http://apache.org/type_test/types1", required = true)
    protected String varUnion;
    @XmlAttribute
    protected String attribUnion;

    /**
     * Gets the value of the varUnion property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVarUnion() {
        return varUnion;
    }

    /**
     * Sets the value of the varUnion property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVarUnion(String value) {
        this.varUnion = value;
    }

    /**
     * Gets the value of the attribUnion property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAttribUnion() {
        return attribUnion;
    }

    /**
     * Sets the value of the attribUnion property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setAttribUnion(String value) {
        this.attribUnion = value;
    }

}

==> cxf-testutils-2.1.3.3-fuse-sources.jar: org/apache/type_test/types1/StructWithUnion.java <==

package org.apache.type_test.types1;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for StructWithUnion complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="StructWithUnion">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="varUnion" type="{http://apache.org/type_test/types1}SimpleUnion"/>
 *       &lt;/sequence>
 *       &lt;attribute name="attribUnion" type="{http://apache.org/type_test/types1}SimpleUnion" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "StructWithUnion", propOrder = {
    "varUnion"
})
public class StructWithUnion {

    @XmlElement(required = true)
    protected String varUnion;
    @XmlAttribute
    protected String attribUnion;

    /**
     * Gets the value of the varUnion property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVarUnion() {
        return varUnion;
    }

    /**
     * Sets the value of the varUnion property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVarUnion(String value) {
        this.varUnion = value;
    }

    /**
     * Gets the value of the attribUnion property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAttribUnion() {
        return attribUnion;
    }

    /**
     * Sets the value of the attribUnion property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setAttribUnion(String value) {
        this.attribUnion = value;
    }

}
